﻿Option Strict On

Imports Infragistics.Win
Imports Infragistics.Win.UltraWinTree

Public Class CustomizedUltraTree
    Inherits UltraTree

    Private _IndexColumn As UltraTreeNodeColumn = Nothing
    Private _ValueColumn As UltraTreeNodeColumn = Nothing

    Public Sub New()
        InitializeComponent()

        Me.Initialize()
    End Sub

    Private Sub Initialize()
        Dim rootColumnSet As UltraTreeColumnSet = Me.ColumnSettings.RootColumnSet
        rootColumnSet.Columns.Clear()

        With Me
            .DisplayStyle = UltraTreeDisplayStyle.WindowsVista
            .ViewStyle = ViewStyle.OutlookExpress
            .FullRowSelect = True
            .HideSelection = False
            .ExpansionIndicatorSize = New Size(0, 0)
            .ScrollBounds = ScrollBounds.ScrollToLastItem

            With .ColumnSettings
                .BorderStyleCell = UIElementBorderStyle.Solid
                .AutoFitColumns = AutoFitColumns.ResizeAllColumns
                .CellAppearance.BorderColor = SystemColors.Control
                .HeaderStyle = HeaderStyle.WindowsXPCommand
            End With
        End With


        _IndexColumn = rootColumnSet.Columns.Add("Index")
        With _IndexColumn
            .Text = "Index"
            .DataType = GetType(String)
            .LayoutInfo.PreferredCellSize = New Size(CInt(Me.Width / 2), 0)
            .AllowSorting = DefaultableBoolean.True
            .ShowSortIndicators = DefaultableBoolean.True
            .LayoutInfo.PreferredCellSize = New Size(0, 22)
        End With

        _ValueColumn = rootColumnSet.Columns.Add("Value")
        With _ValueColumn
            .Text = "Value"
            .DataType = GetType(String)
            .LayoutInfo.PreferredCellSize = New Size(CInt(Me.Width / 2), 0)
            .AllowSorting = DefaultableBoolean.True
            .ShowSortIndicators = DefaultableBoolean.True
            .LayoutInfo.PreferredCellSize = New Size(0, 22)
        End With

    End Sub

    Public Sub AddNode(ByVal index As String, ByVal value As String)
        Dim node As New UltraTreeNode(CStr(index))
        Me.Nodes.Add(node)

        node.SetCellValue(_IndexColumn, index)
        node.SetCellValue(_ValueColumn, value)
    End Sub

End Class
